# -*- coding: utf-8 -*-
#
# This file is part of DT assessment framework.
#
# This code is developed to support the framework to estimate earthquake induced downtime 
# and recovery trajectory of buildings 
# proposed by C. Molina Hutt, T. Vahanvaty, P. Kourehpaz. 
#
# The proposed framework can be found in the manuscript entitled 
# "An analytical framework to assess earthquake induceddowntime and model recovery of buildings"
# The manuscript will be submitted to Earthquake Spectra for publication.
# 
# This code will be publicly available on GitHub after the manuscript is published, 
# and it should not be distributed until then.
#
# Contributor(s):
# Pouria Kourehpaz


"""
This module generates downtime assessment outputs

"""
def run_analysis(parameters, files):
    import numpy as np
    import sys
    import repair_class
    import main
    import impeding_delays
    import recovery_trajectory
    
    
    RC_results = repair_class.RC_calc(parameters[0], files[1], files[0], files[2])
    RCmax_RS = np.squeeze(RC_results[0])
    RC = RC_results[1]
    indx_repairable = RC_results[2]
    indx_irreparable = RC_results[3]
    indx_collapse = RC_results[4]
    
    if sum(parameters[2])!=len(RCmax_RS.T)/7:
        sys.exit("Sum of repair phases is not equal to the number of stories")
    
    RT_results = main.RT_calc(parameters[0], parameters[1], parameters[2], parameters[3], files[0], RC, files[1], files[3], files[2])
    
    N_DMG_RC5 = RT_results[3]
    N_DMG_RC3_RS = RT_results[4]
    IF_results = impeding_delays.IF_calc(parameters[0], parameters[4], parameters[5], RCmax_RS, N_DMG_RC5, N_DMG_RC3_RS, files[1], files[2])
    
    IF_output = IF_results
    RT_RC2_RS_days = RT_results[0]
    RT_RC3_RS_days = RT_results[1] 
    RT_RC4_RS_days = RT_results[2]
    story = RC_results[5]
    DT_results = recovery_trajectory.RecTr_calc(story, parameters[2], parameters[6], parameters[7], indx_repairable, indx_irreparable, indx_collapse, IF_output, RT_RC2_RS_days, RT_RC3_RS_days, RT_RC4_RS_days, RCmax_RS, N_DMG_RC3_RS)
    return