function Downtime_deaggregation(int)

%% Plot the deaggregation of repair classes (Robustness)
RC_Deaggregation = xlsread('RC_Deaggregation.xlsx',int,'A1:E12');
colors_gradient=[[237 249 226]./255; [195 231 203]./255; [151 193 190]./255; [158 137 172]./255; [109 53 110]./255];
figure(22) 
Groupnames = categorical({'Shear wall','Slab-column connections','Hot & cold water piping'...
    'Wall partitions & finishing','Suspended ceiling','HVAC','Fire sprinkler system'...
    'Mechanical equipment','Electrical equipment','Curtain walls','Elevator','Staircase'});
Groupnames = reordercats(Groupnames,{'Shear wall','Slab-column connections','Hot & cold water piping'...
    'Wall partitions & finishing','Suspended ceiling','HVAC','Fire sprinkler system'...
    'Mechanical equipment','Electrical equipment','Curtain walls','Elevator','Staircase'});


fig22 = barh(Groupnames,RC_Deaggregation,'stacked');
x = xlabel('Percentage of Realizations');
y = ylabel('Building Component');
% t = title('Graph showing the percentage of realizations in which a building component incurs damage');
leg = legend('Stability','Shelter-in-place','Re-occupancy','Functional Recovery','Full Recovery');
xlim([0 100])

for k=1:5
fig22(k).BarWidth = 0.5;
fig22(k).FaceColor = 'flat';
end
 
for k=1:5
fig22(k).FaceColor = colors_gradient(6-k,:);
fig22(k).EdgeColor = colors_gradient(6-k,:);
end
set(gca,'TickLength',[0 0])
FormatFigure(3.35,2.75);

%% To plot the de-aggregation of mean downtime

RT_Deaggregation_data = xlsread('Downtime_deaggregation.xlsx',int,'A1:E16');

Governing_IF = zeros(1,4);
GoverningRT = zeros(1,4);
temp = zeros(16,1);
for j=1:16
    temp(j,1) = sum(RT_Deaggregation_data(j,:));
end
for i=1:4
    j=i-1;
    for p=1:4
        if temp(4*j+p,1) == max(temp(4*j+1:4*j+4,1))
            Governing_IF(1,i) = p;
        end
    end
end

figure(21)
Y=[1:2:8,11:2:18,21:2:28,31:2:38];
fig20 = barh(Y,RT_Deaggregation_data,'stacked');
x = xlabel('Time (days)');
y = ylabel('Repair Path');
xlim([0 450])
xticks([0 100:100:400])
% yticks([0 7.5 15.5 23.5 32])

colors=[[118 85 100]; [140 90 150] ; [130 100 165] ; [175 150 170] ; [170 162 195] ;...
    [108 168 180] ; [125 195 187] ; [190 225 207] ; [168 230 195 ] ; [220 250 215 ] ; [221 245 220 ]; [240 250 231] ]./255;
% colors=[[78 45 60]; [130 80 140] ; [90 60 115] ; [135 100 130] ; [170 162 195] ;...
%     [68 128 140] ; [115 185 177] ; [150 185 167] ; [168 230 195 ] ; [220 250 215 ] ; [221 245 220 ]; [240 250 231] ]./255;

% make the colors lighter
colors1=[[184 157 185] ; [172 174 195] ; [208 198 215] ; [205 225 225] ; [226 243 230]]./255;

% colors1=[[75 2 75] ; [100 100 150] ; [135 105 150] ; [125 175 175] ; [180 225 190]]./255;

for k=1:5
fig20(k).BarWidth = 0.8;
fig20(k).FaceColor = 'flat';
% fig20(k).EdgeColor = 'flat';
end

% fig20(1).FaceColor = colors1(1,:);
fig20(1).EdgeColor = colors1(1,:);
% fig20(2).FaceColor = colors1(3,:);
fig20(2).EdgeColor = colors1(2,:);
% fig20(3).FaceColor = colors1(4,:);
fig20(3).EdgeColor = colors1(3,:);
% fig20(4).FaceColor = colors1(6,:);
fig20(4).EdgeColor = colors1(4,:);
% fig20(5).FaceColor = colors1(8,:);
fig20(5).EdgeColor = colors1(5,:);

% for k=1:5
% fig20(k).FaceAlpha = 0.5;
% fig20(k).EdgeAlpha = 0.3;
% end

% Dark colour for governing sequence in each repair path
for i=1:4
    j=i-1;
    fig20(1).CData(4*j+Governing_IF(i),:) = colors1(1,:);
    fig20(2).CData(4*j+Governing_IF(i),:) = colors1(2,:);
    fig20(3).CData(4*j+Governing_IF(i),:) = colors1(3,:);
    fig20(4).CData(4*j+Governing_IF(i),:) = colors1(4,:);
    fig20(5).CData(4*j+Governing_IF(i),:) = colors1(5,:);
end
% For reconstruction path
% fig20(1).CData(17,:) = colors(1,:);
% fig20(2).CData(17,:) = colors(3,:);
% fig20(3).CData(17,:) = colors(4,:);
% fig20(4).CData(17,:) = colors(6,:);
% fig20(5).CData(17,:) = colors(8,:);

% Lighter colour for not governing sequences in each repair path
Notgoverning_IF = 1:16;
for i=1:4
    j=i-1;
    Notgoverning_IF(4*j+Governing_IF(i)) = 0;
end
for j=1:16
    if Notgoverning_IF(j) ~= 0
    i=Notgoverning_IF(j);
    fig20(1).CData(i,:) = colors1(1,:);
    fig20(2).CData(i,:) = colors1(2,:);
    fig20(3).CData(i,:) = colors1(3,:);
    fig20(4).CData(i,:) = colors1(4,:);
    fig20(5).CData(i,:) = colors1(5,:);
    end
end

FormatFigure(2.25,2.75)
yticks([])

%{
% Plot the Average Annual Downtime and Vulenrability curves

Downtime_Ratio = xlsread('VulnerabilityFunction.xlsx',1,'A1:E4');

ReturnPeriod = [100;475;975;2475;4975];
colors_gradient=[[237 249 226]./255; [195 231 203]./255; [151 193 190]./255; [158 137 172]./255; [109 53 110]./255];
AAD_RC4 = sum(Downtime_Ratio(:,4)./ReturnPeriod)*100;

Contribution_C = sum(Downtime_Ratio(1,:));
Contribution_RD = sum(Downtime_Ratio(2,:));
Contribution_RT = sum(Downtime_Ratio(3,:));
AAD_RC2 = 0;
for i=1:5
    AAD_RC2 = AAD_RC2 + Downtime_Ratio(4,i)./ReturnPeriod(i)*100;
end
figure(19)
fig19a = semilogx(ReturnPeriod,Downtime_Ratio(1,:),'-o','color',colors_gradient(5,:),'LineWidth',2,'MarkerSize',3);
hold on
fig19b = semilogx(ReturnPeriod,Downtime_Ratio(2,:),'-o','color',colors_gradient(4,:),'LineWidth',2,'MarkerSize',3);
fig19c = semilogx(ReturnPeriod,Downtime_Ratio(3,:),'-o','color',colors_gradient(3,:),'LineWidth',2,'MarkerSize',3);
fig19d = semilogx(ReturnPeriod,Downtime_Ratio(4,:),'--o','color','k','LineWidth',2,'MarkerSize',3);
hold off
xlim([100 5000])
axis([0 5000 0 1.1])
xticks([100 475 975 2475 4975])
FormatFigure(3.25,2.25)

figure(20)
pie([Contribution_C, Contribution_RD,Contribution_RT]);
colormap([colors_gradient(5,:);colors_gradient(4,:);colors_gradient(3,:)]);
FormatFigure(2.25,2.25)
%}

