function PelicunData2MATLAB(Folder_Path,n_real)
% Variable Definitions
% n_real = == total number of realizations = 2000;


%Data Imports                   ( Read data carefully and make neccessary modifications to extents, file names)
%1) Repair time data with fragility identifiers i.e. text and numbers 
[ ~,~,RT_RawData] = xlsread(append(Folder_Path,'DV_rec_time.csv'),1);
RT_data = RT_RawData(:,2:end);

for j=1:size(RT_data,2)
    temp1 = RT_data(3,j);
    temp2 = temp1{1};
    temp3 = str2double(temp2(1));
    temp4 = num2cell(temp3);
    RT_data{4,j} = cell2mat(temp4);
end
    

%2) Repair class table information with fragility identifiers
[ ~,~,RCT] = xlsread(append(Folder_Path,'Repair_Class_Table.xlsx'),1,'A3:N38');    

%3) Damaged component information (Quantity of each damaged component in each damage state for each realization)
DSdata = xlsread(append(Folder_Path,'DMG.csv'),'B5:AAN2004');               

%4) Demolition due to Resdiual Drift data
Residual_Drift = xlsread(append(Folder_Path,'DL_summary.csv'),'C2:C2001');

%5) Collapse data
Collapse = xlsread(append(Folder_Path,'DL_summary.csv'),'B2:B2001');

%6) Total Economic loss (in $) for each realization
Total_Economic_Loss = xlsread(append(Folder_Path,'DL_summary.csv'),'E2:E2001');

%8) Read a file that has a story identifier for each component 
% Row A: Fragility Identifier (Same as 1st row in 'DV_Rec_Time')
% Row B: PG Identifier (Same as 2nd row in 'DV_Rec_Time')
% Row C: Story Identifier for eacg PG 
Story_Identifier = xlsread(append(Folder_Path,'Floor&Direction_Identifier.xlsx'),'B3:AAN3');

% Create a matrix with only the repair times (numerical format) for all PGs
PG_RepairTimes = RT_data(5:end,:);
PG_RepairTimes = cell2mat(PG_RepairTimes);

% The repair time and economic loss per component matrix have data only for realizations that do not collapse or
% lead to demolition 
% To ensure uniformity,  make the size = n_PGxn_real by adding rows 
% with zero time for realizations that lead to collapse or demolition
[n_Nocollapse , n_PG] = size(RT_data);
PGTimes_All = zeros(n_real,n_PG);
j=0;
for i=1:n_real
    if Residual_Drift(i,1) == 0 && Collapse(i,1) == 0
        j=j+1;
        PGTimes_All(i,:) = PG_RepairTimes(j,:);
    end
end

% To get damage state information
DSdata_temp1 = zeros(n_real,n_PG);
for i=1:n_PG
    for j=1:n_real
        if DSdata(j,i) ~= 0
            DSdata_temp1(j,i) = RT_data{4,i};
        end
    end
end
DamageState  = DSdata_temp1;
% To ensure uniformity in results,  make damage state data for collapse and
% demolition realizations equal to zero. 
for i=1:n_real
    if Residual_Drift(i,1) == 1 || Collapse(i,1) == 1
        DamageState(i,:) = 0;
    end
end  

% xlswrite(append(Folder_Path,'DamageState.xlsx'),DamageState,1,'A2:AAM2001')

%% Repair class matrix

% Create an array with a repair sequence identifier for each PG
RS_Identifier = zeros(1,n_PG);
for j=1:n_PG
    RS_Identifier(1,j) = cell2mat(vlookup(RCT,RT_data{1,j},7,1));
end
% Create the repair class matrix without considering the damage thresholds
% for Stability and Shelter-in-place criteria's
Repair_Class = zeros(n_real,n_PG);
for i=1:n_real
    for j=1:n_PG
        switch DamageState(i,j)
            case(0)
                Repair_Class(i,j) = 0;
            case(1)
                Repair_Class(i,j) = cell2mat(vlookup(RCT,RT_data{1,j},4,1));
            case(2)
                Repair_Class(i,j) = cell2mat(vlookup(RCT,RT_data{1,j},5,1));
            case(3)
                Repair_Class(i,j) = cell2mat(vlookup(RCT,RT_data{1,j},6,1));
        end
    end
end

% To determine repair class based on damage thresholds, first determine the
% number of fragility components that can hinder RC4 or RC5
k=1;
for j=1:size(RCT,1)
    if max(cell2mat(RCT(j,3:6))) >= 4
        n_RC4_comp(k) = cell2mat(RCT(j,2));
        k=k+1;
    end
end
k=1;
for j=1:size(RCT,1)
    if max(cell2mat(RCT(j,3:6))) == 5
        n_RC5_comp(k) = cell2mat(RCT(j,2));
        k=k+1;
    end
end  
k=1;
for j=1:size(RCT,1)
    if max(cell2mat(RCT(j,3:6))) == 4
        n_RC4not5_comp(k) = cell2mat(RCT(j,2));
        k=k+1;
    end
end 
% Determine number of fragility components related to RS3 (exterior
% components)
k=1;
for j=1:size(RCT,1)
    if cell2mat(RCT(j,7)) == 3
        n_RS3_comp(k) = cell2mat(RCT(j,2));
        k=k+1;
    end
end  

% Determine the damaged quantity of each component that hinders RC4 or RC5  in terms of FEMA P-58 fragility quantities 
n_RC4_damaged = zeros(size(n_RC4_comp,2),n_real);
n_RC5_damaged = zeros(size(n_RC5_comp,2),n_real);

% Stability and shelter-in-place thresholds depend on two criterias: 
%   (1) the 50% damage threshold on each floor
%   (2) Damage threshold that if exceeded across ALL floor hinders the shelter-in-place or stability recovery state, i.e., 
%(The FEMA P-58 UNSAFE PLACARD Median damage limit for damage state corresponding to hindering shelter-in-place recovery state)
RC_50percent_criteria = Repair_Class;
RC_FEMA_criteria = Repair_Class;
% Creat a separate excel file which gives the recovery state hindered for each realization 
RecoveryState = zeros(1,n_real);
for i=1:n_real
    m=1;m1=1;m2=1;
    Temp_RC4=0;
    Temp_RC5_1=0;Temp_RC5_2=0;
    switch max(Repair_Class(i,:)) 
        case(0)
        RecoveryState(1,i) = 0;
        
        case(1)
        RecoveryState(1,i) = 1;
        
        case(2)
        RecoveryState(1,i) = 2;
        
        case(3)
        RecoveryState(1,i) = 3;
        
        case(4)
        for p = 1:size(n_RC4_comp,2)  
            for j=1:n_PG
                if strcmp(RCT{n_RC4_comp(p),1},RT_data{1,j}) == 1 && Repair_Class(i,j) == 4
                    % 50% criteria
                    if DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1)) >= 0.5*cell2mat(RCT(n_RC4_comp(p),9))
                        Temp_RC4(m) = 4;
                        m=m+1;
                        RC_50percent_criteria(i,j)=4;
                    else
                        RC_50percent_criteria(i,j)=3;
                    end
                    % FEMA P-58 threshold criteria
                    n_RC4_damaged(p,i) = n_RC4_damaged(p,i) + DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
                    if n_RC4_damaged(p,i) / cell2mat(RCT(n_RC4_comp(p),10)) >  cell2mat(RCT(n_RC4_comp(p),11))
                        RC_FEMA_criteria(i,j) = 4;
                    else
                        RC_FEMA_criteria(i,j) = 3;
                    end
                    
                end 
                
            end
        end
        RecoveryState(1,i) = max(Temp_RC4);
        
        case(5)
        for p = 1:size(n_RC5_comp,2)  
            for j=1:n_PG
                if strcmp(RCT{n_RC5_comp(p),1},RT_data{1,j}) == 1 && Repair_Class(i,j) == 5
                    % 50% criteria
                    if DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1)) >= 0.5*cell2mat(RCT(n_RC5_comp(p),9))
                        Temp_RC5_1(m1) = 5;
                        m1=m1+1;
                        RC_50percent_criteria(i,j)=5;
                    elseif DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1)) < 0.5*cell2mat(RCT(n_RC5_comp(p),9))
                        RC_50percent_criteria(i,j)=3;
                    end
                    % FEMA P-58 threshold criteria
                    n_RC5_damaged(p,i) = n_RC5_damaged(p,i) + DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
                    if n_RC5_damaged(p,i) / cell2mat(RCT(n_RC5_comp(p),10)) >  cell2mat(RCT(n_RC4_comp(p),12))
                        RC_FEMA_criteria(i,j) = 5;
                        Temp_RC5_2(m2) = 5;
                        m2=m2+1;
                    else
                        RC_FEMA_criteria(i,j) = 3;
                    end
                end            
            end
        end
        RecoveryState(1,i) = max(max(Temp_RC5_1),max(Temp_RC5_2));
        
        % Adjust for cases when stability is not hindered but
        % shelter-in-place is hindered when the max repair class is 5
        if RecoveryState(1,i) ~= 5
        for p = 1:size(n_RC4_comp,2)  
            for j=1:n_PG
                if strcmp(RCT{n_RC4_comp(p),1},RT_data{1,j}) == 1 && Repair_Class(i,j) >= 4 
                    % 50% criteria
                    if DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1)) >= 0.5*cell2mat(RCT(n_RC4_comp(p),9)) && strcmp(RT_data{1,j},'B1049.012')==0
                        Temp_RC4(m) = 4;
                        m=m+1;
                        RC_50percent_criteria(i,j)=4;
                    else
                        RC_50percent_criteria(i,j)=3;
                    end
                    % FEMA P-58 threshold criteria
                    if n_RC4_damaged(p,i) / cell2mat(RCT(n_RC4_comp(p),10)) >  cell2mat(RCT(n_RC4_comp(p),11)) && strcmp(RT_data{1,j},'B1049.012')==0
                        RC_FEMA_criteria(i,j) = 4;
                    else
                        RC_FEMA_criteria(i,j) = 3;
                    end
                end     
            end
        end
        RecoveryState(1,i) = max(Temp_RC4);
        end
        
        % Adjust for cases when max repair class is 5, but a component that
        % does not hinder RC5 is triggered with RC4
        for p = 1:size(n_RC4not5_comp,2)  
            for j=1:n_PG
                if strcmp(RCT{n_RC4not5_comp(p),1},RT_data{1,j}) == 1 && Repair_Class(i,j) == 4
                    % 50% criteria
                    if DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1)) >= 0.5*cell2mat(RCT(n_RC4_comp(p),9))
                        Temp_RC4(m) = 4;
                        m=m+1;
                        RC_50percent_criteria(i,j)=4;
                    else
                        RC_50percent_criteria(i,j)=3;
                    end
                    % FEMA P-58 threshold criteria
                    n_RC4_damaged(p,i) = n_RC4_damaged(p,i) + DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
                    if n_RC4_damaged(p,i) / cell2mat(RCT(n_RC4_comp(p),10)) >  cell2mat(RCT(n_RC4_comp(p),11))
                        RC_FEMA_criteria(i,j) = 4;
                    else
                        RC_FEMA_criteria(i,j) = 3;
                    end
                    
                end 
                
            end
        end
        
        if RecoveryState(1,i) ~=5 && RecoveryState(1,i) ~=4
            RecoveryState(1,i) = 3;
        end
        
    end
end

% Determine the resultant repair class from the maximum of the above two
% thresholds
for i=1:n_real
    for j=1:n_PG
        Repair_Class(i,j) = max(RC_50percent_criteria(i,j)  ,   RC_FEMA_criteria(i,j));
    end
end


% Currently exterior facade components that hinder stability are not tagged
% with a repair class of 5 because these do not need to "repaired" for
% stability or shelter-in-place, but only need the damaged panels need to
% be removed to achieve stability. Hence we check if more than 50% of the
% facade panels are damaged which would trigger a cordon around a building 
n_RS3_damaged = zeros(size(n_RS3_comp,2),n_real);
for i=1:n_real
    for p = 1:size(n_RS3_comp,2)  
        for j=1:n_PG
            if strcmp(RCT{n_RS3_comp(p),1},RT_data{1,j}) == 1 && Repair_Class(i,j) >= 3
                n_RS3_damaged(p,i) = n_RS3_damaged(p,i) + DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
            end     
        end
    end
end
RS3_Stability = zeros(1,n_real);    
for i=1:n_real    
    for p = 1:size(n_RS3_comp,2)
        if n_RS3_damaged(p,i) > 0.5*cell2mat(RCT(n_RS3_comp(p),12))
            RS3_Stability(1,i)=5;
        end
    end
end

%% Number of damaged components matrix per recovery state (USED TO ALLOCATE WORKERS)
Number_DC_RC2 = zeros(n_real,n_PG);
Number_DC_RC3 = zeros(n_real,n_PG);
Number_DC_RC4 = zeros(n_real,n_PG);
Number_DC_RC5 = zeros(n_real,n_PG);
% RC2
for i=1:n_real
    for j=1:n_PG
        if Repair_Class(i,j) >=2 
            Number_DC_RC2(i,j) = DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
        end
    end
end
% Adjust elevator damaged components for this case study (We need to do
% this because elevators have simultaneous damage states)
temp1=zeros(1,n_real);
for i=1:n_real
    p=1;
    for j=1:n_PG
        if strcmp(RT_data{1,j},"D1014.011") == 1 
            location_elev1(p) = j; 
            temp1(p,i) = Number_DC_RC2(i,j);
            p=p+1;
        end
    end
end
temp2=zeros(1,n_real);
for i=1:n_real
    p=1;
    for j=1:n_PG
        if strcmp(RT_data{1,j},"D1014.011_ridr") == 1 
            location_elev2(p) = j; 
            temp2(p,i) = Number_DC_RC2(i,j);
            p=p+1;
        end
    end
end
% Put the damaged components only in the first elevator component and make
% the rest equal to zero
for i=1:n_real
    for j=location_elev1(1)
        Number_DC_RC2(i,j) = max(max(temp1(:,i)),max(temp2(:,i)));
    end
    for j=location_elev1(2:end)
        Number_DC_RC2(i,j) = 0;
    end
    for j=location_elev2
        Number_DC_RC2(i,j) = 0;
    end
end

% RC3
for i=1:n_real
    for j=1:n_PG
        if Repair_Class(i,j) >=3 
            Number_DC_RC3(i,j) = DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
        end
    end
end
% RC4
for i=1:n_real
    for j=1:n_PG
        if Repair_Class(i,j) >=4 
            Number_DC_RC4(i,j) = DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
        end
    end
end
% RC5
for i=1:n_real
    for j=1:n_PG
        if Repair_Class(i,j) ==5 
            Number_DC_RC5(i,j) = DSdata(i,j) / cell2mat(vlookup(RCT,RT_data{1,j},8,1));
        end
    end
end

%% Write excel files for input in downtime framework
PGTimes_All = transpose(PGTimes_All);
Repair_Class_All = transpose(Repair_Class);
Residual_Drift = transpose(Residual_Drift);
Number_DC_RC2 = transpose(Number_DC_RC2); 

Number_DC_RC3 = transpose(Number_DC_RC3);
Number_DC_RC4 = transpose(Number_DC_RC4);
Number_DC_RC5 = transpose(Number_DC_RC5);
Total_Economic_Loss = transpose(Total_Economic_Loss);
Collapse = transpose(Collapse);
RS_Story_Identifier(:,1) = RS_Identifier;
RS_Story_Identifier(:,2) = Story_Identifier;

xlswrite(append(Folder_Path,'PGTimes_All.xlsx'),PGTimes_All)
xlswrite(append(Folder_Path,'Repair_Class_All.xlsx'),Repair_Class_All)
xlswrite(append(Folder_Path,'Number_DC_RC2.xlsx'),Number_DC_RC2)
xlswrite(append(Folder_Path,'Number_DC_RC3.xlsx'),Number_DC_RC3)
xlswrite(append(Folder_Path,'Number_DC_RC4.xlsx'),Number_DC_RC4)
xlswrite(append(Folder_Path,'Number_DC_RC5.xlsx'),Number_DC_RC5)
xlswrite(append(Folder_Path,'AllReal_RDcases.xlsx'),Residual_Drift)
xlswrite(append(Folder_Path,'AllReal_TotalLoss.xlsx'),Total_Economic_Loss)
xlswrite(append(Folder_Path,'AllReal_CollapseCases.xlsx'),Collapse)
xlswrite(append(Folder_Path,'RS_Story_Identifier.xlsx'),RS_Story_Identifier)
xlswrite(append(Folder_Path,'RS3_Stability.xlsx'),RS3_Stability)
    
            

