function [Downtime_Max_median , DT_Variation] = Repair_Sequencing(Folder_Path,Repair_Class,n_real,n_Floors,n_Floors_AG,Phases)
% n_real=2000;
% n_Floors=16;
% Repair_Class = 'RC2';
        
n_Phase = size(Phases,1);

% Call the worker allocation function to get the reducec repair time
[Summary_RT ] = Worker_Allocation(Folder_Path,Repair_Class,n_real,n_Floors,Phases);
% 

filename1 = append(Folder_Path,'AllReal_ImpedingFactors.xlsx');
filename2 = append(Folder_Path,'IF_CM.xlsx');
filename3 = append(Folder_Path,'IF_Summary_RS.xlsx');

IF_General = xlsread(filename1,1,'A1:BXX6'); 
IF_CM = xlsread(filename2,1,'A1:BXX7'); 
IF_Summary_RS = xlsread(filename3,1,'A1:BXX7'); 

% Consider collapse realizations
% Get the output file from SP3 which indicates if collapse has occurred 
% for that realization
% If the value = 1 for that realization, it indicates collapse
filename4 = append(Folder_Path,'AllReal_CollapseCases.xlsx');
Collapse = xlsread(filename4,1,'A1:BXX1');
n_collapse=0;
for i=1:n_real 
    if Collapse(1,i)==1
        n_collapse = n_collapse+1;
    end
end

% Consider demolition due to Resdiual Drift
% Get the output file from SP3 which indicates if residual drift will deem 
% the building irrepairable and lead to demolition 
% If the value = 1 for that realization, it indicates demolition due to 
% residual drift
filename5 = append(Folder_Path,'AllReal_RDCases.xlsx');
Residual_Drift = xlsread(filename5,1,'A1:BXX1');
n_RDcollapse=0;
for i=1:n_real 
    if Residual_Drift(1,i)==1
        n_RDcollapse = n_RDcollapse+1;
    end
end

% Read the Utility Time Delays
filename6 = append(Folder_Path,'Utility_Downtime.xlsx');
Utility_DT = xlsread(filename6,1,'A1:BXX3');


% The repair times given above are in the same sequence as given in REDi
% documents

% To plot the stepping function
Downtime_PathA = zeros(n_Floors+4,n_real);         % Downtime for structural + interior + mechanical + electrical repairs. 
Downtime_PathB = zeros(n_Floors+4,n_real);         % Downtime for exterior repairs
Downtime_PathC = zeros(n_Floors+4,n_real);         % Downtime for elevator repairs
Downtime_PathD = zeros(n_Floors+4,n_real);         % Downtime for staircase repairs 
Downtime_PathE = zeros(n_Floors+4,n_real);         % Downtime for collapse or irreparable realizations 
Downtime_Max = zeros(n_Floors+4,n_real);       % Governing Downtime

for i=1:n_real
IF = IF_Summary_RS(:,i);
Repair_Time = Summary_RT(:,i);
% The sequence in which the repairs are plotted is same as the sequence 
% used for priority of worker allocations: 
%   RS1: Structural repairs
%   RS7: Staircase repairs
%   RS6: Elevator repairs
%   RS3: Exterior repairs
%   RS2: Interior repairs
%   RS4: Mechanical repairs
%   RS5: Electrical repairs

DT=zeros(7*n_Floors,2);


%% REPAIR PHASE SEQUENCING: PHASE 1

% The max repair time for each repair sequence in each repair phase:
RT_max_P_RS1 = zeros(n_Phase,1);
RT_max_P_RS2 = zeros(n_Phase,1);
RT_max_P_RS3 = zeros(n_Phase,1);
RT_max_P_RS4 = zeros(n_Phase,1);
RT_max_P_RS5 = zeros(n_Phase,1);
RT_max_P_RS6 = zeros(n_Phase,1);
RT_max_P_RS7 = zeros(n_Phase,1);

for j = Phases(1,1):Phases(1,2) 
    p=j-1;
    if j == Phases(1,1)
        
    DT(1,1)=IF(1,1);                        % RS1
    DT(1,2)=Repair_Time(1,1);
    
    DT(2,1)=max(IF(2,1),DT(1,1)+DT(1,2));   % RS2
    DT(2,2)=Repair_Time(2,1);
    
    % Impeding factor for exterior repairs should be included for RC2 and RC3 only
    % The repair times for components not included in the desired recovery state is already be zero. 
    if Repair_Class == 'RC2' | Repair_Class == 'RC3'
    DT(3,1) = IF(3,1); else; DT(3,1) = 0;  end      % RS3
    DT(3,2)=Repair_Time(3,1);
    
    % Impeding factor for mechanical equipment repairs should be included only for RC2
    if Repair_Class == 'RC2'; DT(4,1) = max(IF(4,1),DT(1,1)+DT(1,2)); else; DT(4,1) = 0;end      % RS4
    DT(4,2)=Repair_Time(4,1);
    
    % Impeding factor for electrical equipment repairs should be included only for RC2
    if Repair_Class == 'RC2'; DT(5,1) = max(IF(5,1),DT(1,1)+DT(1,2)); else; DT(5,1) = 0;end      % RS5
    DT(5,2)=Repair_Time(5,1);

    % Impeding factor for elevator should be included only for RC2
    if Repair_Class == 'RC2'; DT(6,1) = IF(6,1); else; DT(6,1) = 0;end      % RS6
    DT(6,2)=Repair_Time(6,1);
    
    DT(7,1)=IF(7,1);  %RS7                     
    DT(7,2)=Repair_Time(7,1);
    
    else                        % i.e. if it is not the first floor
        
    % RS1
    % The start time of RS1 on all floors in this repair phase is the same
    % as the start time of RS1 on the first floor of that same phase
    DT(7*p+1,1)= DT(1,1);                                  
    % Duration of current phase =  repair time of current phase
    DT(7*p+1,2)= Repair_Time(7*p+1,1); 
    % The max repair time for RS1 in this phase is: (It will be used to
    % determine the start of repairs for the next phase)
    RT_max_P_RS1(1) = max([Repair_Time(7*p+1,1),Repair_Time(1,1),RT_max_P_RS1(1)]);
    
    % RS2
    DT(7*p+2,1)=DT(2,1);
    DT(7*p+2,2)=Repair_Time(7*p+2,1);
    % The max repair time for RS2 in this phase is: (It will be used to
    % determine the start of repairs for the next phase)
    RT_max_P_RS2(1) = max([Repair_Time(7*p+2,1),Repair_Time(2,1),RT_max_P_RS2(1)]);
    
    % RS3
    DT(7*p+3,1)=DT(3,1);
    DT(7*p+3,2)=Repair_Time(7*p+3,1);
    % The max repair time for RS3 in this phase is: (It will be used to
    % determine the start of repairs for the next phase)
    RT_max_P_RS3(1) = max([Repair_Time(7*p+3,1),Repair_Time(3,1),RT_max_P_RS3(1)]);
    
     % RS4
    DT(7*p+4,1)=DT(4,1);
    DT(7*p+4,2)=Repair_Time(7*p+4,1);
    % The max repair time for RS4 in this phase is: (It will be used to
    % determine the start of repairs for the next phase)
    RT_max_P_RS4(1) = max([Repair_Time(7*p+4,1),Repair_Time(4,1),RT_max_P_RS4(1)]);
    
    % RS5
    DT(7*p+5,1)=DT(5,1);
    DT(7*p+5,2)=Repair_Time(7*p+5,1);
    % The max repair time for RS5 in this phase is: (It will be used to
    % determine the start of repairs for the next phase)
    RT_max_P_RS5(1) = max([Repair_Time(7*p+5,1),Repair_Time(5,1),RT_max_P_RS5(1)]);
    
    %RS6
    DT(7*p+6,1)=DT(6,1);
    DT(7*p+6,2)=Repair_Time(7*p+6,1);
    % The max repair time for RS6 in this phase is: (It will be used to
    % determine the start of repairs for the next phase)
    RT_max_P_RS6(1) = max([Repair_Time(7*p+6,1),Repair_Time(6,1),RT_max_P_RS6(1)]);
    
    %RS7
    DT(7*p+7,1)=DT(7,1);                                    
    DT(7*p+7,2)=Repair_Time(7*p+7,1);
    % The max repair time for RS7 in this phase is: (It will be used to
    % determine the start of repairs for the next phase)
    RT_max_P_RS7(1) = max([Repair_Time(7*p+7,1),Repair_Time(7,1),RT_max_P_RS7(1)]);
    
    end
end

%% REPAIR PHASE SEQUENCING: PHASE 2 TO LAST PHASE

for phase=2:n_Phase
    for j=Phases(phase,1):Phases(phase,2)
    p=j-1;
        
    if j == Phases(phase,1)    
    % The start time of repairs = maximum end time of repairs across all floors in the previous phase
    
    %RS1
    DT(7*p+1,1)= DT(7*(p-1)+1,1)+RT_max_P_RS1(phase-1); 
    DT(7*p+1,2)= Repair_Time(7*p+1,1);     
     
    %RS2
    % Start of repairs for RS2,RS4,RS5 = maximum of {
    % end of structural repairs in the current phase   &   end of repairs
    % of this sequence in previous phase }
    DT(7*p+2,1)=max((DT(7*p+1,1)+Repair_Time(7*p+1,1)),(DT(7*(p-1)+2,1)+RT_max_P_RS2(phase-1)));
    DT(7*p+2,2)=Repair_Time(7*p+2,1);
    
    %RS3
    DT(7*p+3,1)=DT(7*(p-1)+3,1)+RT_max_P_RS3(phase-1);
    DT(7*p+3,2)=Repair_Time(7*p+3,1);
    
    %RS4
    DT(7*p+4,1)=max((DT(7*p+1,1)+Repair_Time(7*p+1,1)),(DT(7*(p-1)+4,1)+RT_max_P_RS4(phase-1)));
    DT(7*p+4,2)=Repair_Time(7*p+4,1);
    
    %RS5
    DT(7*p+5,1)=max((DT(7*p+1,1)+Repair_Time(7*p+1,1)),(DT(7*(p-1)+5,1)+RT_max_P_RS5(phase-1)));
    DT(7*p+5,2)=Repair_Time(7*p+5,1);
    
    %RS6
    DT(7*p+6,1)=DT(7*(p-1)+6,1)+RT_max_P_RS6(phase-1);     
    DT(7*p+6,2)=Repair_Time(7*p+6,1);
    
    %RS7
    DT(7*p+7,1)=DT(7*(p-1)+7,1)+RT_max_P_RS7(phase-1);
    DT(7*p+7,2)=Repair_Time(7*p+7,1);
       
    else
    %RS1   
    % Start time = Start of that RS at the beginning of this phase
    DT(7*p+1,1)= DT(7*(Phases(phase,1)-1)+1,1);
    DT(7*p+1,2)= Repair_Time(7*p+1,1); 
    RT_max_P_RS1(phase) = max([Repair_Time(7*p+1,1),Repair_Time(7*(p-1)+1,1),RT_max_P_RS1(phase)]);
    
    %RS2
    DT(7*p+2,1)=DT(7*(Phases(phase,1)-1)+2,1);
    DT(7*p+2,2)=Repair_Time(7*p+2,1);
    RT_max_P_RS2(phase) = max([Repair_Time(7*p+2,1),Repair_Time(7*(p-1)+2,1),RT_max_P_RS2(phase)]);
    
    %RS3
    DT(7*p+3,1)=DT(7*(Phases(phase,1)-1)+3,1);
    DT(7*p+3,2)=Repair_Time(7*p+3,1);
    RT_max_P_RS3(phase) = max([Repair_Time(7*p+3,1),Repair_Time(7*(p-1)+3,1),RT_max_P_RS3(phase)]);
    
    %RS4
    DT(7*p+4,1)=DT(7*(Phases(phase,1)-1)+4,1);
    DT(7*p+4,2)=Repair_Time(7*p+4,1);
    RT_max_P_RS4(phase) = max([Repair_Time(7*p+4,1),Repair_Time(7*(p-1)+4,1),RT_max_P_RS4(phase)]);
    
    %RS5
    DT(7*p+5,1)=DT(7*(Phases(phase,1)-1)+5,1);
    DT(7*p+5,2)=Repair_Time(7*p+5,1);
    RT_max_P_RS5(phase) = max([Repair_Time(7*p+5,1),Repair_Time(7*(p-1)+5,1),RT_max_P_RS5(phase)]);
    
    %RS6
    DT(7*p+6,1)=DT(7*(Phases(phase,1)-1)+6,1);
    DT(7*p+6,2)=Repair_Time(7*p+6,1);
    RT_max_P_RS6(phase) = max([Repair_Time(7*p+6,1),Repair_Time(7*(p-1)+6,1),RT_max_P_RS6(phase)]);

    %RS7
    DT(7*p+7,1)=DT(7*(Phases(phase,1)-1)+7,1);
    DT(7*p+7,2)=Repair_Time(7*p+7,1);
    RT_max_P_RS7(phase) = max([Repair_Time(7*p+7,1),Repair_Time(7*(p-1)+7,1),RT_max_P_RS7(phase)]);
    
    end
    end
end
% If the first repair for a sequence is required on the nth floor, then
% make downtime of all floors from 1 to n-1 equal to time required for
% inspection
for RS=1:7
    for j=1:n_Floors
    p=j-1;
        if DT(p*7+RS,2) == 0
            DT(p*7+RS,1) = IF_General(1,i);
        else
            break
        end
    end
end
        

% To plot the stepping function
Downtime_PathA(1,i)=-25;
Downtime_PathA(2,i)=0;
Downtime_PathA(3,i)=0;
Downtime_PathB(1,i)=-25;
Downtime_PathB(2,i)=0;
Downtime_PathB(3,i)=0;
Downtime_PathC(1,i)=-25;
Downtime_PathC(2,i)=0;
Downtime_PathC(3,i)=0;
Downtime_PathD(1,i)=-25;
Downtime_PathD(2,i)=0;
Downtime_PathD(3,i)=0;
Downtime_PathE(1,i)=-25;
Downtime_PathE(2,i)=0;
Downtime_PathE(3,i)=0;
for s=1:n_Floors
    k=s-1;
    % If IF_RS1 governs IF for path1, Downtime_S1 = start time for RS1 + RT for RS1 +  max repair time of RS2,RS4,RS5 which happen in parallel
    % If IF_RS2 governs IF for path1, Downtime_S1 = start time for RS2 + RT for RS2  
    % IF IF_RS4 or IF_RS5 govern, then Downtime_S1 is similar to the case when IF_RS2 governs
    Downtime_PathA(s+3,i)=max([ DT(7*k+1,1) + DT(7*k+1,2) + max([DT(7*k+2,2),DT(7*k+4,2),DT(7*k+5,2)])...  
                        , DT(7*k+2,1)+DT(7*k+2,2), DT(7*k+4,1)+DT(7*k+4,2), DT(7*k+5,1)+DT(7*k+5,2), Downtime_PathA(s+2,i)]);
    
    Downtime_PathB(s+3,i)=max(DT(7*k+3,1)+DT(7*k+3,2) , Downtime_PathB(s+2,i));
    
    Downtime_PathC(s+3,i)=max(DT(7*k+6,1)+DT(7*k+6,2) , Downtime_PathC(s+2,i));
    
    Downtime_PathD(s+3,i)=max(DT(7*k+7,1)+DT(7*k+7,2) , Downtime_PathD(s+2,i)); 
end 

Downtime_PathA(s+4,i)=Downtime_PathA(s+3,i)+20;
Downtime_PathB(s+4,i)=Downtime_PathB(s+3,i)+20;
Downtime_PathC(s+4,i)=Downtime_PathC(s+3,i)+20;
Downtime_PathD(s+4,i)=Downtime_PathD(s+3,i)+20;

% Accounting for collapse and demolition due to residual drift 
if Residual_Drift(1,i) == 1 || Collapse(1,i) == 1
    Downtime_PathE(4,i) = max(IF);
    Downtime_PathE(5:end-1,i) = Downtime_PathE(4,i)+14*n_Floors;          % Building Replacement Time = 2 weeks per story
    Downtime_PathE(end,i) = Downtime_PathE(end-1,i)+20;
    Downtime_PathA(2:end,i)=0;Downtime_PathB(2:end,i)=0;Downtime_PathC(2:end,i)=0;Downtime_PathD(2:end,i)=0;
end

% The governing stepping function is the stepping curve with the maximum
% time from the above four curves at each level
for r=1:n_Floors+4
    Downtime_Max(r,i) = max([Downtime_PathA(r,i),Downtime_PathB(r,i), Downtime_PathC(r,i),Downtime_PathD(r,i),Downtime_PathE(r,i)]);
end

% Accounting for utility delay time
if Repair_Class == 'RC2'
    if max(Utility_DT(:,i)) > Downtime_Max(end-1,i)
        Downtime_Max(4:end-1,i) = max(Utility_DT(:,i));          
        Downtime_Max(end,i) = Downtime_Max(end-1,i)+20;
    end
end


% Stepping function shows recovery only for all floors above grade since we
% are not concerned with recovery of the building below grade. Hence the
% first step in the plot represents the time for repair of all floors below
% grade and first floor above grade
Y=[n_Floors_AG , n_Floors_AG , 0 , 0 , 0, 0 , 0 ,1:n_Floors_AG,n_Floors_AG]./n_Floors_AG*100;

if Repair_Class == 'RC2'
    fig_numb = 222;
elseif Repair_Class == 'RC3'
    fig_numb = 322;
    Downtime_PathC(:,i) = 0;
elseif Repair_Class == 'RC4'
    fig_numb = 422;
    Downtime_PathC(:,i) = 0;
    Downtime_PathB(:,i) = 0;
end

figure(fig_numb)

% Uncomment to plot stepping function for each realization
% e = stairs(Downtime_Max(:,i),Y,'color',[0.67 0.67 0.67 0.1]);
% e.LineWidth = 0.5;
hold on
end

% To get the median stepping function, we sort the matrix of the governing
% stepping function for all realizations with respective to the last row
% i.e. we sort it with respect to maximum time
Downtime_Max_Sorted = zeros(n_Floors+4,n_real);
[~, temp2] = sort(Downtime_Max(end,:),2);
% varibale 'temp2' describes the position of the sorted matrix wrt the
% originial matrix
for i=1:n_real
    k=temp2(i);
    for j=1:n_Floors+4
        Downtime_Max_Sorted(j,i) = Downtime_Max(j,k);
    end
end

% Find the realizations (medI1 and medI2) which corresponds to the median 
% times. Also, calculate the 10th and 90th percentile realization
% Note that the total number of realizations is considered to be even
for i=1:n_real
    for j=n_Floors+4
        if Downtime_Max(j,i) == Downtime_Max_Sorted(j,(n_real/2))
            medI1 = i;
        end
        if Downtime_Max(j,i) == Downtime_Max_Sorted(j,(n_real/2 + 1))
            medI2 = i;
        end
        
        %Find the 90th percentile realization
        if Downtime_Max(j,i) == Downtime_Max_Sorted(j,ceil((0.9*n_real)))
            prctile90 = i;
        end
        
        %Find the 10th percentile realization
        if Downtime_Max(j,i) == Downtime_Max_Sorted(j,ceil((0.1*n_real)))
            prctile10 = i;
        end
    end
end

% The median value is assigned to the larger of the two middle values.
median_real=medI2; 

Downtime_Max_median = Downtime_Max(:,median_real);
Downtime_Max_90 = Downtime_Max(:,prctile90);
Downtime_Max_10 = Downtime_Max(:,prctile10);

f = stairs(Downtime_Max_median(:,1),Y,'k');
f.LineWidth = 2;

g = stairs(Downtime_Max_90(:,1),Y,'--k');
g.LineWidth = 2;

h = stairs(Downtime_Max_10(:,1),Y,'--k');
h.LineWidth = 2;
hold off
leg = legend([f ,g ],{'Median','10th & 90th percentile'});
axis([-30 500 -5 105])
xticks([0 100 200 300 400 500 600 700])
x = xlabel('Days after the earthquake');
y = ylabel('Building Usability (%)');
FormatFigure(3.5,2.5);
set(gca,'TickLength',[0 0])

%% Write the stepping functions
xlswrite(append(Folder_Path,'DT_stepfunc_',Repair_Class,'.xlsx'),Downtime_Max)
xlswrite(append(Folder_Path,'DT_Medianstepfunc_',Repair_Class,'.xlsx'),Downtime_Max_median)
xlswrite(append(Folder_Path,'DT_Prct90_stepfunc_',Repair_Class,'.xlsx'),Downtime_Max_90)
xlswrite(append(Folder_Path,'DT_Prct10_stepfunc_',Repair_Class,'.xlsx'),Downtime_Max_10)

%% To plot median times with contribution of each repair sequence
Downtime_PathA_median = Downtime_PathA(:,median_real);
Downtime_PathB_median = Downtime_PathB(:,median_real);
Downtime_PathC_median = Downtime_PathC(:,median_real);
Downtime_PathD_median = Downtime_PathD(:,median_real);
Downtime_PathE_median = Downtime_PathE(:,median_real);

% Impeding factors:
Time_IF = zeros(3,2);
Time_IF_CM = zeros(7,2);
for i=median_real

    Time_IF(4,1) = IF_General(1,i);                                             %Inspection
    Time_IF(3,1) = Time_IF(4,1) ; Time_IF(3,2) = IF_General(2,i);                 %Inspection+Financing
    Time_IF(2,1) = Time_IF(4,1) ; Time_IF(2,2) = IF_General(3,i); Time_IF(2,3) = IF_General(4,i);       %Inspection+Engineering+Permitting                          
    Time_IF(1,1) = Time_IF(4,1) ; Time_IF(1,2) = IF_General(5,i);                 %Inspection + Building stabilization time 

    Time_IF_CM(7,1) = IF_General(1,i); Time_IF_CM(7,2) = IF_CM(1,i);          %Inspection+Contractor moblization for structural repairs
    Time_IF_CM(6,1) = IF_General(1,i); Time_IF_CM(6,2) = IF_CM(2,i);          %Inspection+Contractor moblization for interior repairs

    % Impeding factor for exterior repairs shall only be included if desired
    % recovery state is RC2 or RC3
    if Repair_Class == 'RC2' | Repair_Class == 'RC3'
        Time_IF_CM(5,1) = IF_General(1,i); Time_IF_CM(5,2) = IF_CM(3,i);          %Inspection+Contractor moblization for exterior repairs
    end

    % Impeding factors for elevator, mechanical and electrical
    % equipments shall be included only if desired recovery state is RC2
    if Repair_Class == 'RC2'
        Time_IF_CM(4,1) = IF_General(1,i); Time_IF_CM(4,2) = IF_CM(4,i);          %Inspection+Contractor moblization for mechanical repairs
        Time_IF_CM(3,1) = IF_General(1,i); Time_IF_CM(3,2) = IF_CM(5,i);          %Inspection+Contractor moblization for electrical repairs
        Time_IF_CM(2,1) = IF_General(1,i); Time_IF_CM(2,2) = IF_CM(6,i);          %Inspection+Contractor moblization for elevator repairs
    end
    Time_IF_CM(1,1) = IF_General(1,i); Time_IF_CM(1,2) = IF_CM(7,i);          %Inspection+Contractor moblization for staircase repairs

    Time_Utility(:,1) = Utility_DT(:,i);
end

Y_Utility = 83:7:97;
Y_IF = 54:7:75;
Y_IF_CM = 5:7:47;

% PLOT THE STEPPING FUNCTIONS OF THE MEDIAN REALIZATIONS
if Repair_Class == 'RC2'
    fig_numb = 223;
elseif Repair_Class == 'RC3'
    fig_numb = 323;
elseif Repair_Class == 'RC4'
    fig_numb = 423;
end
figure(fig_numb)
colorline=[[5 112 176]./255; [35 139 69]./255; [254 153 41]./255; [0.839 0.153 0.157]; [106 81 163]./255];
a = stairs(Downtime_PathA_median(:,1),Y,'color',[34 94 168]./255);
a.LineWidth = 1.5;
hold on
b = stairs(Downtime_PathB_median(:,1),Y,'color',[77 175 74]./255);
b.LineWidth = 1.5;
c = stairs(Downtime_PathC_median(:,1),Y,'color',[25 180 170]./255);
c.LineWidth = 1.5;
d = stairs(Downtime_PathD_median(:,1),Y,'color',[2 0 80]./255);
d.LineWidth = 1.5;
if Residual_Drift(1,median_real) == 1 || Collapse(1,median_real) ==1
    f = stairs(Downtime_PathE_median(:,1),Y,'color',colorline(4,:));
    f.LineWidth = 1.5;
end
g = stairs(Downtime_Max_median(:,1),Y,'--k');
g.LineWidth = 2;

axis([-30 300 -5 105])
xticks([0 50 100 150 200 250 300 350 400])
x = xlabel('Days after the earthquake');
y = ylabel('Building Usability (%)');
% t = title(append('Stepping path to Recovery: ', Repair_Class));

% Plot the general impeding factors
fig23a = barh(Y_IF,Time_IF,'stacked','ShowBaseLine','off');
fig23a(1).BarWidth = 0.5;
fig23a(2).BarWidth = 0.5;
fig23a(3).BarWidth = 0.5;
alpha(fig23a,0.5)

% Plot the contractor mobilization impeding factors
fig23b = barh(Y_IF_CM,Time_IF_CM,'stacked','ShowBaseLine','off');
fig23b(1).BarWidth = 0.5;
fig23b(2).BarWidth = 0.5;
alpha(fig23b,0.5)

% Plot utlity downtimes if desired recovery state is Functional recovery
if Repair_Class == 'RC2'
fig23c = barh(Y_Utility,Time_Utility,'ShowBaseLine','off');
fig23c.BarWidth = 0.5;
alpha(fig23c,0.5)
end
hold off
leg = legend('Structural+Interior+Mech.+Elec. eqpt.','Staircase repairs','Elevator repairs','Exterior repairs','Re-construction','Governing stepping function','AutoUpdate','off');


colors=[[78 45 60]; [130 80 140] ; [90 60 115] ; [135 100 130] ; [170 162 195] ;...
    [68 128 140] ; [115 185 177] ; [150 185 167] ; [168 230 195 ] ; [220 250 215 ] ; [221 245 220 ]; [240 250 231] ]./255;
% Label the descrition of downtime component  (General impeding factors)
% text(50,76,'Impeding Factors','fontsize',8,'linewidth',3)
%{
text(3,Y_IF(4)+3.5,'Inspection','fontsize',8,'linewidth',2,'color','k')
text(3,Y_IF(3)+3.5,'Financing','fontsize',8,'linewidth',2,'color','k')
text(3,Y_IF(2)+3.5,'Engineering + Permitting','fontsize',8,'linewidth',2,'color','k')
text(3,Y_IF(1)+3.5,'Building Stabilization','fontsize',8,'linewidth',2,'color','k')

% Label the descrition of downtime component  (Contractor mobilization impeding factors)
% text(30,48,'Impeding Factors for Contractor Moblization (CM)','fontsize',9,'linewidth',3)
text(3,Y_IF_CM(7)+3.5,'Contractor: RS1','fontsize',8,'linewidth',2,'color','k')
text(3,Y_IF_CM(6)+3.5,'Contractor: RS2','fontsize',8,'linewidth',2,'color','k')
if Repair_Class == 'RC2' | Repair_Class == 'RC3'
text(3,Y_IF_CM(5)+3.5,'Contractor: RS3','fontsize',8,'linewidth',2,'color','k')
end
if Repair_Class == 'RC2'
text(3,Y_IF_CM(4)+3.5,'Contractor: RS4','fontsize',8,'linewidth',2,'color','k')
text(3,Y_IF_CM(3)+3.5,'Contractor: RS5','fontsize',8,'linewidth',2,'color','k')
text(3,Y_IF_CM(2)+3.5,'Contractor: RS6','fontsize',8,'linewidth',2,'color','k')
end
text(3,Y_IF_CM(1)+3.5,'Contractor: RS7','fontsize',8,'linewidth',2,'color','k')

if exist('fig23c')
% Label the descritipn of downtime component  (Utility delay time)
% text(50,100,'Utility Delay Time','fontsize',8,'linewidth',3)
text(3,Y_Utility(3)+3.5,'Water system','fontsize',8,'linewidth',2,'color','k')
text(3,Y_Utility(2)+3.5,'Natural Gas','fontsize',8,'linewidth',2,'color','k')
text(3,Y_Utility(1)+3.5,'Electrical system','fontsize',8,'linewidth',2,'color','k')
end
%}

% Adjusting the colors of individual bar plots
% colors=[[170 162 195] ;[108 168 180] ; [125 195 187] ; [190 225 207] ;...
%      [168 230 195 ] ; [220 250 215 ] ; [221 245 220 ]; [240 250 231] ]./255;

% Edgecolor
for k=1:3
%     fig23a(k).EdgeColor = 'flat';
    fig23a(k).FaceColor = 'flat';
end
for k=1:2
%     fig23b(k).EdgeColor = 'flat';
    fig23b(k).FaceColor = 'flat';
end

for k=1:4
fig23a(1).CData(k,:) = colors(2,:);
end
fig23a(2).CData(1,:) = colors(7,:);
fig23a(2).CData(2,:) = colors(7,:);
fig23a(2).CData(3,:) = colors(7,:);
fig23a(2).CData(4,:) = [1,1,1]; 
fig23a(3).CData(1,:) = [1,1,1]; 
fig23a(3).CData(2,:) = colors(10,:);
fig23a(3).CData(3,:) = [1,1,1]; 
fig23a(3).CData(4,:) = [1,1,1]; 

for k=1:7
fig23b(1).CData(k,:) = colors(2,:);
end
fig23b(2).CData(1,:) = colors(7,:);
fig23b(2).CData(2,:) = colors(7,:);
fig23b(2).CData(3,:) = colors(7,:);
fig23b(2).CData(4,:) = colors(7,:);
fig23b(2).CData(5,:) = colors(7,:);
fig23b(2).CData(6,:) = colors(7,:);
fig23b(2).CData(7,:) = colors(7,:);

if exist('fig23c')
fig23c.FaceColor = 'flat';
% fig23c.EdgeColor = 'flat';
fig23c.CData(1,:) = colors(7,:);
fig23c.CData(2,:) = colors(7,:);
fig23c.CData(3,:) = colors(7,:);
end

FormatFigure(5.25,4.75);
%}
%% To get the median downtime of each floor
MedianDT_eachfloor = zeros(size(Downtime_Max,1),1);
for j=1:size(Downtime_Max,1)
    MedianDT_eachfloor(j,1) = median(Downtime_Max(j,:));
end
if Repair_Class == 'RC2'
    fig_numb = 225;
elseif Repair_Class == 'RC3'
    fig_numb = 325;
elseif Repair_Class == 'RC4'
    fig_numb = 425;
end
figure(fig_numb)
a = stairs(MedianDT_eachfloor(:,1),Y,'color',[34 94 168]./255,'linewidth',2);
axis([-30 325 -5 105])
xticks([0 100 200 300 400 500 600 700])
x = xlabel('Days after the earthquake');
y = ylabel('Building Usability (%)');
FormatFigure(3,2.25);
set(gca,'TickLength',[0 0])

%% To plot the range of total downtime for the desired recovery state against SPUR limits
% SPUR report 'Defining Resilience' (2009) gave us target recovery times
% that should be achieved in order to make San Franciso resilient. We plot
% the downtime calculated by our model against these target times for RC2
% and RC4

Target_DT_RC2 = [30*4 30*12 30*24 30*36];
Target_DT_RC3 = [30*4 30*12 30*24 30*36];
Target_DT_RC4 = [30*4 30*12 30*24 30*36];
n_Target = [0; 0; 0; 0; 0];

switch Repair_Class 
    case('RC2')
        Target_Downtime = Target_DT_RC2;
    case('RC3')
        Target_Downtime = Target_DT_RC3;
    case('RC4')
        Target_Downtime = Target_DT_RC4;
end
    
for i=1:n_real
    if Downtime_Max(end-1,i) <= Target_Downtime(1)
        n_Target(1) = n_Target(1) +1;
    elseif Downtime_Max(end-1,i) <= Target_Downtime(2) && Downtime_Max(end-1,i) > Target_Downtime(1)
        n_Target(2) = n_Target(2) +1;
    elseif Downtime_Max(end-1,i) <= Target_Downtime(3) && Downtime_Max(end-1,i) > Target_Downtime(2)
        n_Target(3) = n_Target(3) +1;
    elseif Downtime_Max(end-1,i) <= Target_Downtime(4) && Downtime_Max(end-1,i) > Target_Downtime(3)
        n_Target(4) = n_Target(4) +1;
    elseif Downtime_Max(end-1,i) > Target_Downtime(4)
        n_Target(5) = n_Target(5) +1;
    end
end       

DT_Variation = n_Target ./ n_real * 100;



end
